pub type SqlType = (Text, Text, Text, Text, Numeric, Numeric, SmallInt);Expand description
The SQL type of all of the columns on this table
pub type SqlType = (Text, Text, Text, Text, Numeric, Numeric, SmallInt);The SQL type of all of the columns on this table